@@ -1,4 +1,6 @@
 
+import re
+
 from celery import task,chord,group,chain
 from celery.signals import task_success
 from celery.utils.log import get_task_logger
@@ -23,6 +25,7 @@ def chunk_dict(d, n):
 
 @task()
 def doReset():
+    letters = ['a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z']
     lemmas = loadLemmas()
     #lemma_job = group(addLemmas.si(x) for x in chunk_dict(lemmas,10000))
     wfs,spells,trans = loadWF()
@@ -30,7 +33,11 @@ def doReset():
     #spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
     #trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
     ajob = group([addLemmas.si(lemmas),addSpells.si(spells),addTrans.si(trans)])
-    c2 = (deleteall.si() | loadCats.si() | ajob | addWFS.si(wfs) | addRelationships.si(wfs))
+    #reljob = group([addSpellRelationships.si(wfs),addTransRelationships.si(wfs)])
+    spelljob = chord([collectSpellRelationships.si(wfs,l) for l in letters])(addSpellRelationships.s())
+    transjob = chord([collectTransRelationships.si(wfs,l) for l in letters])(addTransRelationships.s())
+    reljob = group([spelljob,transjob])
+    c2 = (deleteall.si() | loadCats.si() | ajob | addWFS.si(wfs) | reljob)
     res = c2()
     res.get()
 
@@ -80,19 +87,39 @@ def loadWF():
     return wfs,spells,trans
 
 @task()
-def addRelationships(wfs):
-    wf = WordForm.objects.all()
-    pas = []
+def collectSpellRelationships(wfs,l):
+    wf = WordForm.objects.filter(lemma__label__istartswith=l)
     sas = []
     for w in wf:
         for s in wfs[str(w.pk)]['Spellings']:
             spell = Orthography.objects.get(spelling = s[0])
             sas.append(SpelledAs(word_form=w,orthography=spell,frequency=s[1]))
+    SpelledAs.objects.bulk_create(sas)
+    #return sas
+
+
+@task()
+def addSpellRelationships(out):
+    pass
+    #for l in out:
+    #    SpelledAs.objects.bulk_create(l)
+
+@task()
+def collectTransRelationships(wfs,l):
+    wf = WordForm.objects.filter(lemma__label__istartswith=l)
+    pas = []
+    for w in wf:
         for t in wfs[str(w.pk)]['Transcriptions']:
             pron = Transcription.objects.get(transcription = t)
-            sas.append(PronouncedAs(word_form=w,transcription=pron))
-    SpelledAs.objects.bulk_create(sas)
+            pas.append(PronouncedAs(word_form=w,transcription=pron))
     PronouncedAs.objects.bulk_create(pas)
+    #return pas
+
+@task()
+def addTransRelationships(out):
+    pass
+    #for l in out:
+    #    PronouncedAs.objects.bulk_create(l)
 
 @task()
 def addWFS(wfs):
