@@ -5,13 +5,9 @@ from django.db.models import Sum
 from .models import Lemma,WordForm,Orthography,Transcription
 
 
-def checkDict(freqDict):
-    if FreqDict.objects.filter(Name=freqDict).exists():
-        return True
-    return False
 
 def lookupFreq(word):
-    total_freq = sum([x.Frequency for x in Lemma.objects.filter(wordform__Orthographies__Spelling = word).distinct()])
+    total_freq = sum([x.frequency for x in Lemma.objects.filter(wordform__orthographies__spelling = word).distinct()])
     return total_freq
 
 #def lookupStress(word,freqDict):
@@ -19,17 +15,21 @@ def lookupFreq(word):
 #    return [q.StressPattern for q in qs]
 
 def lookupCat(word):
-    qs = Lemma.objects.filter(wordform__Orthographies__Spelling = word).distinct().order_by('-Frequency')
-    #qs = Orthography.objects.filter(Label=word).order_by('-Word__Frequency')
+    qs = Lemma.objects.filter(wordform__orthographies__spelling = word).distinct().order_by('-frequency')
     if len(qs) == 0:
         return 'NA'
-    cat = qs[0].Category.Label
+    cat = qs[0].category.label
     if cat == 'ADV':
         cat = 'R'
     return cat.lower()
 
 def filterNGrams(ngram_path):
-    spells = set([str(x) for x in Orthography.objects.all()])
+    qs = Orthography.objects.all()#.prefetch_related()
+    #qs = qs.exclude(spelling__contains="'")
+    #qs = qs.exclude(spelling__contains=".")
+    #qs = qs.exclude(spelling__contains=",")
+    #qs = qs.exclude(spelling__contains='"')
+    spells = set([str(x) for x in qs])
     orig_path = os.path.join(ngram_path,'original')
     trim_path = os.path.join(ngram_path,'trimmed')
     files = os.listdir(orig_path)
