@@ -10,6 +10,8 @@ from django.shortcuts import render,redirect
 from django.http import HttpResponse
 from django.core.files import File
 
+from ngrams.utils import in_trigram_context_entropy
+
 from .models import *
 from .forms import *
 from .helper import fetch_celex_resource
@@ -69,7 +71,7 @@ def reset(request):
 def string_selection(request):
     if request.method == 'POST':
         form = StringForm(request.POST)
-        if form.is_valid() and form.cleaned_data['reset']:
+        if form.is_valid():
             response = HttpResponse(mimetype='text/csv')
             response['Content-Disposition'] = 'attachment; filename="strings.csv"'
             writer = csv.writer(response)
@@ -82,19 +84,44 @@ def string_selection(request):
                 qs = qs.exclude(orthographies__spelling__contains='"')
             if form.cleaned_data['exclude_titlecase']:
                 qs = qs.exclude(orthographies__spelling__regex="^[A-Z]")
-            #if form.cleaned_data['phone_length'] != '0':
-            #    qs = filter(lambda q: len(q.Transcriptions.
-            qs = qs.filter(transcriptions__cvskel = forms.cleaned_data['cvskel'])
-            for q in qs:
+            qs = qs.filter(transcriptions__cvskel = form.cleaned_data['cvskel'])
+            writer.writerow(["orth_one","orth_two","trans_one",'trans_two',
+                                "cat_one","cat_two","freq_one","freq_two",
+                                "lemma_one","lemma_two",
+                                "lemma_freq_one","lemma_freq_two",
+                                "phon_distance","in_context_entropy",
+                                ])
+            for i in range(len(qs)):
+                q = qs[i]
                 if len(q.transcriptions.all()) != 1:
                     continue
-                t = q.transcriptions.all()[0]
-                s = q.orthographies.all()[0]
-                f = q.frequency
-                c = q.lemma.category.label
-                L = q.lemma.label
-                LF = q.lemma.frequency
-                writer.writerow([s,t,c,f,L,LF])
+                t_one = str(q.transcriptions.all()[0]).encode('ascii')
+                o_one = [str(x) for x in q.orthographies.all()]
+                for j in range(i+1,len(qs)):
+                    s = qs[j]
+                    if len(s.transcriptions.all()) != 1:
+                        continue
+                    t_two = str(s.transcriptions.all()[0]).encode('ascii')
+                    o_two = [str(x) for x in s.orthographies.all()]
+                    phon_dist = get_phone_dist(re.sub('\'','',t_one),re.sub('\'','',t_two))
+                    #if not is_neighbour(re.sub('\'','',t_one),re.sub('\'','',t_two)):
+                    #    if t_one != t_two:
+                    #        continue
+                    #    phon_dist = "homophone"
+                    #else:
+                    #    phon_dist = "neighbour"
+                    in_context_entropy = in_trigram_context_entropy(o_one,o_two)
+                    c_one = str(q.lemma.category.label).encode('ascii')
+                    c_two = str(s.lemma.category.label).encode('ascii')
+                    f_one = q.frequency
+                    f_two = s.frequency
+                    L_one = str(q.lemma.label).encode('ascii')
+                    L_two = str(s.lemma.label).encode('ascii')
+                    LFreq_one = q.lemma.frequency
+                    LFreq_two = s.lemma.frequency
+                    writer.writerow([':'.join(o_one),':'.join(o_two),t_one,t_two,
+                                        c_one,c_two,f_one,f_two,L_one,L_two,
+                                        LFreq_one,LFreq_two,phon_dist,in_context_entropy])
             return response
     form = StringForm()
     return render(request,'celex/form.html',{'form':form})
